<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt">
<context>
    <name>NotificationActionsComboWidget</name>
    <message>
        <location filename="../notificationwidgets.cpp" line="103"/>
        <source>Actions:</source>
        <translation>Veiksmai:</translation>
    </message>
    <message>
        <location filename="../notificationwidgets.cpp" line="122"/>
        <source>OK</source>
        <translation>Gerai</translation>
    </message>
</context>
<context>
    <name>Notifyd</name>
    <message>
        <location filename="../notifyd.cpp" line="226"/>
        <source>Clear All</source>
        <translation>Išvalyti visus</translation>
    </message>
    <message>
        <location filename="../notifyd.cpp" line="234"/>
        <source>Options</source>
        <translation>Parinktys</translation>
    </message>
    <message numerus="yes">
        <location filename="../notifyd.cpp" line="241"/>
        <location filename="../notifyd.cpp" line="299"/>
        <location filename="../notifyd.cpp" line="319"/>
        <source>%n Unattended Notification(s)</source>
        <translation>
            <numerusform>%n nepastebėtas pranešimas</numerusform>
            <numerusform>%n nepastebėti pranešimai</numerusform>
            <numerusform>%n nepastebėtų pranešimų</numerusform>
        </translation>
    </message>
</context>
</TS>
